import requests
from requests import Response

base_url = 'https://mc-t.ru/api/'


class MctClient:
    def __init__(self, key: str):
        self.session = requests.Session()
        self.key = key

    def send_post(self, method: str, kwargs: dict) -> Response:
        """
        Метод запроса к апи

        :param method: наименование метода
        :param kwargs: данные для метода
        :return:
        """

        data = {
            'key': self.key,
            'method': method,
            'kwargs': kwargs
        }

        return self.session.post(f'{base_url}', json=data)

    def get_votes(self, days: int = 30) -> dict:
        """
        Метод получает количество голосов вашего проекта за промежуток времени

        :param days: Временной промежуток в днях
        :return:
        """
        return self.send_post('getVotes', {'days': days, }).json()



import setuptools

setuptools.setup(
    name='mct_sdk',
    version='0.1.2',
    author="IO-HOST DEV",
    author_email="admin@1-0.su",
    url="https://github.com/Underlor/mct_sdk",
    description="MCT python SKD",
    install_requires=['requests', ],
    packages=setuptools.find_packages(),
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description="GIT: https://github.com/Underlor/mct_sdk",
)
